@@ -1,5 +1,7 @@
 """File translation command"""
 
+import logging
+
 import click
 from cligj import format_opt
 
@@ -7,6 +9,25 @@ from .helpers import resolve_inout
 from . import options
 import rasterio
 from rasterio.coords import disjoint_bounds
+from rasterio.windows import Window
+
+
+logger = logging.getLogger(__name__)
+
+
+# Geographic (default), projected, or Mercator switch.
+projection_geographic_opt = click.option(
+    '--geographic',
+    'projection',
+    flag_value='geographic',
+    help="Bounds in geographic coordinates.")
+
+projection_projected_opt = click.option(
+    '--projected',
+    'projection',
+    flag_value='projected',
+    default=True,
+    help="Bounds in input's own projected coordinates (the default).")
 
 
 # Clip command
@@ -24,23 +45,25 @@ from rasterio.coords import disjoint_bounds
     type=click.Path(exists=True),
     help='Raster dataset to use as a template for bounds')
 @format_opt
+@projection_geographic_opt
+@projection_projected_opt
 @options.creation_options
 @click.pass_context
-def clip(
-        ctx,
-        files,
-        output,
-        bounds,
-        like,
-        driver,
-        creation_options):
-    """Clips a raster using bounds input directly or from a template raster.
+def clip(ctx, files, output, bounds, like, driver, projection,
+         creation_options):
+    """Clips a raster using projected or geographic bounds.
 
     \b
       $ rio clip input.tif output.tif --bounds xmin ymin xmax ymax
       $ rio clip input.tif output.tif --like template.tif
 
-    If using --bounds, values must be in coordinate reference system of input.
+    The values of --bounds are presumed to be from the coordinate
+    reference system of the input dataset unless the --geographic option
+    is used, in which case the values may be longitude and latitude
+    bounds. Either JSON, for example "[west, south, east, north]", or
+    plain text "west south east north" representations of a bounding box
+    are acceptable.
+
     If using --like, bounds will automatically be transformed to match the
     coordinate reference system of the input.
 
@@ -50,18 +73,17 @@ def clip(
       $ rio clip input.tif output.tif --bounds $(fio info features.shp --bounds)
 
     """
-
     from rasterio.warp import transform_bounds
 
-    verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
-
-    with rasterio.Env(CPL_DEBUG=verbosity > 2):
+    with ctx.obj['env']:
 
         output, files = resolve_inout(files=files, output=output)
         input = files[0]
 
         with rasterio.open(input) as src:
             if bounds:
+                if projection == 'geographic':
+                    bounds = transform_bounds('epsg:4326', src.crs, *bounds)
                 if disjoint_bounds(bounds, src.bounds):
                     raise click.BadParameter('must overlap the extent of '
                                              'the input raster',
@@ -83,16 +105,32 @@ def clip(
             else:
                 raise click.UsageError('--bounds or --like required')
 
-            window = src.window(*bounds)
+            bounds_window = src.window(*bounds)
+            bounds_window = bounds_window.intersection(
+                Window(0, 0, src.width, src.height))
 
-            out_kwargs = src.meta.copy()
+            # Get the window with integer height
+            # and width that contains the bounds window.
+            out_window = bounds_window.round_lengths(op='ceil')
+
+            height = int(out_window.height)
+            width = int(out_window.width)
+
+            out_kwargs = src.profile
             out_kwargs.update({
                 'driver': driver,
-                'height': window[0][1] - window[0][0],
-                'width': window[1][1] - window[1][0],
-                'transform': src.window_transform(window)
-            })
+                'height': height,
+                'width': width,
+                'transform': src.window_transform(out_window)})
             out_kwargs.update(**creation_options)
 
+            if 'blockxsize' in out_kwargs and out_kwargs['blockxsize'] > width:
+                del out_kwargs['blockxsize']
+                logger.warn("Blockxsize removed from creation options to accomodate small output width")
+            if 'blockysize' in out_kwargs and out_kwargs['blockysize'] > height:
+                del out_kwargs['blockysize']
+                logger.warn("Blockysize removed from creation options to accomodate small output height")
+
             with rasterio.open(output, 'w', **out_kwargs) as out:
-                out.write(src.read(window=window))
+                out.write(src.read(window=out_window,
+                                   out_shape=(src.count, height, width)))
