@@ -28,20 +28,18 @@ except RuntimeError as e:  # pragma: no cover
     plt = None
 
 
-logger = logging.getLogger('rasterio')
-
 Stats = collections.namedtuple('Stats', ['min', 'max', 'mean'])
 
 # Collect dictionary of functions for use in the interpreter in main()
 funcs = locals()
 
 
-def stats(source):
+def stats(dataset):
     """Return a tuple with raster min, max, and mean."""
-    if isinstance(source, tuple):
-        arr = source[0].read(source[1])
+    if isinstance(dataset, tuple):
+        arr = dataset[0].read(dataset[1])
     else:
-        arr = source
+        arr = dataset
     return Stats(np.min(arr), np.max(arr), np.mean(arr))
 
 
@@ -73,10 +71,9 @@ def main(banner, dataset, alt_interpreter=None):
 @click.pass_context
 def insp(ctx, input, mode, interpreter):
     """Open the input file in a Python interpreter."""
-    verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
-    logger = logging.getLogger('rio')
+    logger = logging.getLogger()
     try:
-        with rasterio.Env(CPL_DEBUG=verbosity > 2):
+        with ctx.obj['env']:
             with rasterio.open(input, mode) as src:
                 main(
                     'Rasterio %s Interactive Inspector (Python %s)\n'
