@@ -43,15 +43,32 @@ Registry of common rio CLI options.  See cligj for more options.
 --vfs: virtual file system.
 """
 
-
-# TODO: move file_in_arg and file_out_arg to cligj
-
-import os.path
+import logging
+import os
+import re
 
 import click
 
 import rasterio
-from rasterio.vfs import parse_path
+import rasterio.shutil
+from rasterio.path import parse_path, ParsedPath, UnparsedPath
+
+
+logger = logging.getLogger(__name__)
+
+
+class IgnoreOptionMarker(object):
+    """A marker for an option that is to be ignored.
+
+    For use in the case where `None` is a meaningful option value,
+    such as for nodata where `None` means "unset the nodata value."
+    """
+
+    def __repr__(self):
+        return 'IgnoreOption()'
+
+
+IgnoreOption = IgnoreOptionMarker()
 
 
 def _cb_key_val(ctx, param, value):
@@ -75,38 +92,58 @@ def _cb_key_val(ctx, param, value):
         out = {}
         for pair in value:
             if '=' not in pair:
-                raise click.BadParameter("Invalid syntax for KEY=VAL arg: {}".format(pair))
+                raise click.BadParameter(
+                    "Invalid syntax for KEY=VAL arg: {}".format(pair))
             else:
                 k, v = pair.split('=', 1)
                 k = k.lower()
                 v = v.lower()
-                out[k] = v
+                out[k] = None if v.lower() in ['none', 'null', 'nil', 'nada'] else v
         return out
 
+
 def abspath_forward_slashes(path):
     """Return forward-slashed version of os.path.abspath"""
     return '/'.join(os.path.abspath(path).split(os.path.sep))
 
+
 def file_in_handler(ctx, param, value):
     """Normalize ordinary filesystem and VFS paths"""
     try:
-        path, archive, scheme = parse_path(value)
-    except ValueError as exc:
-        raise click.BadParameter(str(exc))
-    path_to_check = archive or path
-    if not scheme in ['http', 'https', 's3'] and not os.path.exists(path_to_check):
-        raise click.BadParameter(
-            "Input file {0} does not exist".format(path_to_check))
-    if archive and scheme:
-        archive = abspath_forward_slashes(archive)
-        path = "{0}://{1}!{2}".format(scheme, archive, path)
-    elif scheme and scheme.startswith('http'):
-        path = "{0}://{1}".format(scheme, path)
-    elif scheme == 's3':
-        path = "{0}://{1}".format(scheme, path)
-    else:
-        path = abspath_forward_slashes(path)
-    return path
+        path = parse_path(value)
+        if isinstance(path, UnparsedPath):
+            return path.name
+
+        elif path.scheme and path.is_remote:
+            return path.name
+
+        elif path.archive:
+            if os.path.exists(path.archive) and rasterio.shutil.exists(value):
+                archive = abspath_forward_slashes(path.archive)
+                return "{}://{}!{}".format(path.scheme, archive, path.path)
+            else:
+                raise IOError(
+                    "Input archive {} does not exist".format(path.archive))
+
+        else:
+            if os.path.exists(path.path) and rasterio.shutil.exists(value):
+                return abspath_forward_slashes(path.path)
+            else:
+                raise IOError(
+                    "Input file {} does not exist".format(path.path))
+
+    except Exception:
+        raise click.BadParameter("{} is not a valid input file".format(value))
+
+
+def files_in_handler(ctx, param, value):
+    """Process and validate input file names"""
+    return tuple(file_in_handler(ctx, param, item) for item in value)
+
+
+def files_inout_handler(ctx, param, value):
+    """Process and validate input file names"""
+    return tuple(file_in_handler(ctx, param, item) for item in value[:-1]) + tuple(value[-1:])
 
 
 def from_like_context(ctx, param, value):
@@ -128,21 +165,57 @@ def like_handler(ctx, param, value):
         with rasterio.open(value) as src:
             metadata = src.meta
             ctx.obj['like'] = metadata
-            ctx.obj['like']['transform'] = metadata['affine']
+            ctx.obj['like']['transform'] = metadata['transform']
             ctx.obj['like']['tags'] = src.tags()
+            ctx.obj['like']['colorinterp'] = src.colorinterp
+        return True
+    else:  # pragma: no cover
+        return False
 
 
 def nodata_handler(ctx, param, value):
-    """Get nodata value from a template file or command line."""
+    """Return a float or None"""
+    if value is None or value is IgnoreOption:
+        return value
+    elif value.lower() in ['null', 'nil', 'none', 'nada']:
+        return None
+    else:
+        try:
+            return float(value)
+        except (TypeError, ValueError):
+            raise click.BadParameter(
+                "{!r} is not a number".format(value),
+                param=param, param_hint='nodata')
+
+
+def edit_nodata_handler(ctx, param, value):
+    """Get nodata value from a template file or command line.
+
+    Expected values are 'like', 'null', a numeric value, 'nan', or
+    IgnoreOption. Anything else should raise BadParameter.
+    """
+    if value == 'like' or value is IgnoreOption:
+        retval = from_like_context(ctx, param, value)
+        if retval is not None:
+            return retval
+    return nodata_handler(ctx, param, value)
+
+
+def bounds_handler(ctx, param, value):
+    """Handle different forms of bounds."""
     retval = from_like_context(ctx, param, value)
     if retval is None and value is not None:
         try:
-            retval = float(value)
-        except:
+            value = value.strip(', []')
+            retval = tuple(float(x) for x in re.split(r'[,\s]+', value))
+            assert len(retval) == 4
+            return retval
+        except Exception:
             raise click.BadParameter(
-                "%s is not a number." % repr(value),
-                param=param, param_hint='nodata')
-    return retval
+                "{0!r} is not a valid bounding box representation".format(
+                    value))
+    else:  # pragma: no cover
+        return retval
 
 
 # Singular input file
@@ -153,6 +226,24 @@ file_out_arg = click.argument(
     'OUTPUT',
     type=click.Path(resolve_path=True))
 
+# Multiple input files.
+files_in_arg = click.argument(
+    'files',
+    nargs=-1,
+    type=click.Path(),
+    required=True,
+    metavar="INPUTS...",
+    callback=files_in_handler)
+
+# Multiple files, last of which is an output file.
+files_inout_arg = click.argument(
+    'files',
+    nargs=-1,
+    type=click.Path(),
+    required=True,
+    metavar="INPUTS... OUTPUT",
+    callback=files_inout_handler)
+
 bidx_opt = click.option(
     '-b', '--bidx',
     type=int,
@@ -160,15 +251,23 @@ bidx_opt = click.option(
     help="Input file band index (default: 1).")
 
 bidx_mult_opt = click.option(
+    '-b', '--bidx',
+    type=int,
+    multiple=True,
+    help="Indexes of input file bands.")
+
+# The 'magic' --bidx option is especially for rio-stack, which supports
+# selection of multiple bands from multiple files. It has 'str' type
+# instead of 'int' to support ranges in a syntax like `--bidx 1..3`.
+bidx_magic_opt = click.option(
     '-b', '--bidx',
     multiple=True,
     help="Indexes of input file bands.")
 
 # TODO: may be better suited to cligj
 bounds_opt = click.option(
-    '--bounds',
-    nargs=4, type=float, default=None,
-    help='Output bounds: left bottom right top.')
+    '--bounds', default=None, callback=bounds_handler,
+    help='Bounds: "left bottom right top" or "[left, bottom, right, top]".')
 
 dimensions_opt = click.option(
     '--dimensions',
@@ -200,9 +299,7 @@ output_opt = click.option(
     '-o', '--output',
     default=None,
     type=click.Path(resolve_path=True),
-    help="Path to output file (optional alternative to a positional arg). "
-         "Existing files will be overwritten (`--force-overwrite` is "
-         "implied).")
+    help="Path to output file (optional alternative to a positional arg).")
 
 resolution_opt = click.option(
     '-r', '--res',
@@ -213,7 +310,7 @@ resolution_opt = click.option(
          '--res pixel_width --res pixel_height.')
 
 creation_options = click.option(
-    '--co', 'creation_options',
+    '--co', '--profile', 'creation_options',
     metavar='NAME=VALUE',
     multiple=True,
     callback=_cb_key_val,
@@ -227,14 +324,18 @@ rgb_opt = click.option(
     default=False,
     help="Set RGB photometric interpretation.")
 
-force_overwrite_opt = click.option(
-    '--force-overwrite', 'force_overwrite',
+overwrite_opt = click.option(
+    '--overwrite', 'overwrite',
     is_flag=True, type=bool, default=False,
     help="Always overwrite an existing output file.")
 
 nodata_opt = click.option(
     '--nodata', callback=nodata_handler, default=None,
-    help="New nodata value.")
+    metavar='NUMBER|nan', help="Set a Nodata value.")
+
+edit_nodata_opt = click.option(
+    '--nodata', callback=edit_nodata_handler, default=IgnoreOption,
+    metavar='NUMBER|nan|null', help="Modify the Nodata value.")
 
 like_opt = click.option(
     '--like',
@@ -251,3 +352,11 @@ all_touched_opt = click.option(
     help='Use all pixels touched by features, otherwise (default) use only '
          'pixels whose center is within the polygon or that are selected by '
          'Bresenhams line algorithm')
+
+# Feature collection or feature sequence switch.
+sequence_opt = click.option(
+    '--sequence/--collection',
+    default=True,
+    help="Write a LF-delimited sequence of texts containing individual "
+         "objects (the default) or write a single JSON text containing a "
+         "feature collection object.")
