@@ -12,11 +12,14 @@ except ImportError:
     plt = None
 
 from affine import Affine
+
 import rasterio
-from rasterio.enums import MaskFlags
+from rasterio.enums import Resampling
 from rasterio.errors import NodataShadowWarning
 from rasterio.crs import CRS
 
+from .conftest import requires_gdal2
+
 logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
 
 
@@ -54,11 +57,25 @@ alp_shift_lr = np.array([[1, 1, 0],
                          [0, 1, 0],
                          [0, 0, 0]]).astype('uint8') * 255
 
+# whole mask resampled to (1, 5, 5) array
+resampmask = np.array([[0, 0, 0, 0, 0],
+                       [0, 0, 0, 0, 0],
+                       [1, 1, 1, 1, 1],
+                       [1, 1, 0, 1, 1],
+                       [1, 1, 0, 1, 1]]).astype('uint8') * 255
+
+# whole mask resampled to (1, 5, 5) array
+resampave = np.array([[0, 0, 0, 0, 0],
+                      [1, 1, 1, 1, 1],
+                      [1, 1, 1, 1, 1],
+                      [1, 1, 1, 1, 1],
+                      [1, 1, 0, 1, 1]]).astype('uint8') * 255
+
+
 @pytest.fixture(scope='function')
 def tiffs(tmpdir):
 
     _profile = {
-        'affine': Affine(5.0, 0.0, 0.0, 0.0, -5.0, 0.0),
         'transform': Affine(5.0, 0.0, 0.0, 0.0, -5.0, 0.0),
         'crs': CRS({'init': 'epsg:4326'}),
         'driver': 'GTiff',
@@ -177,6 +194,21 @@ def test_kwargs(tiffs):
         other = src.dataset_mask(window=((1, 4), (1, 4)), boundless=True)
         assert np.array_equal(alp_shift_lr, other)
 
+        other = src.dataset_mask(out_shape=(1, 5, 5))
+        assert np.array_equal(resampmask, other)
+
+        out = np.zeros((1, 5, 5), dtype=np.uint8)
+        other = src.dataset_mask(out=out)
+        assert np.array_equal(resampmask, other)
+
         # band indexes are not supported
         with pytest.raises(TypeError):
             src.dataset_mask(indexes=1)
+
+
+@requires_gdal2(reason="GDAL 2+ required for resampling")
+def test_kwargs_resampling(tiffs):
+    with rasterio.open(str(tiffs.join('rgb_ndv.tif'))) as src:
+        other = src.dataset_mask(out_shape=(1, 5, 5), resampling=Resampling.bilinear) != 0
+        other = other.astype(np.uint8) * 255
+        assert np.array_equal(resampave, other)
