@@ -2,7 +2,6 @@
 Tests of band mask creation, both .msk sidecar and internal.
 """
 
-import pytest
 import rasterio
 from rasterio.enums import MaskFlags
 
@@ -21,11 +20,11 @@ def test_create_internal_mask(data):
 
     # Check that the mask was saved correctly.
     with rasterio.open(str(data.join('RGB.byte.tif'))) as src:
-        assert (mask == src.read_mask()).all()
-        for flags in src.mask_flags:
-            assert flags & MaskFlags.per_dataset
-            assert not flags & MaskFlags.alpha
-            assert not flags & MaskFlags.nodata
+        assert (mask == src.read_masks()).all()
+        for flags in src.mask_flag_enums:
+            assert MaskFlags.per_dataset in flags
+            assert MaskFlags.alpha not in flags
+            assert MaskFlags.nodata not in flags
 
 
 def test_create_sidecar_mask(data):
@@ -41,11 +40,11 @@ def test_create_sidecar_mask(data):
 
     # Check that the mask was saved correctly.
     with rasterio.open(str(data.join('RGB.byte.tif'))) as src:
-        assert (mask == src.read_mask()).all()
-        for flags in src.mask_flags:
-            assert flags & MaskFlags.per_dataset
-            assert not flags & MaskFlags.alpha
-            assert not flags & MaskFlags.nodata
+        assert (mask == src.read_masks()).all()
+        for flags in src.mask_flag_enums:
+            assert MaskFlags.per_dataset in flags
+            assert MaskFlags.alpha not in flags
+            assert MaskFlags.nodata not in flags
 
     # Check the .msk file, too.
     with rasterio.open(str(data.join('RGB.byte.tif.msk'))) as msk:
@@ -63,11 +62,8 @@ def test_create_mask_windowed_sidecar(data):
                 dst.write_mask(mask, window=window)
 
 
-@pytest.mark.xfail(reason="https://github.com/mapbox/rasterio/issues/781")
 def test_create_mask_windowed_internal(data):
     """Writing masks by window with internal mask
-    Currently fails with
-        rasterio.errors.RasterioIOError: Failed to get mask.
     """
     with rasterio.Env(GDAL_TIFF_INTERNAL_MASK=True):
         with rasterio.open(str(data.join('RGB.byte.tif')), 'r+') as dst:
