@@ -1,3 +1,6 @@
+"""Unittests for rasterio.plot"""
+
+
 import numpy as np
 import pytest
 
@@ -10,53 +13,58 @@ except ImportError:
     plt = None
 
 import rasterio
-from rasterio.plot import show, show_hist, get_plt
+from rasterio.plot import (show, show_hist, get_plt,
+                           plotting_extent, adjust_band)
 from rasterio.enums import ColorInterp
 
-@pytest.mark.skipif(plt is None,
-                    reason="requires matplotlib")
-def test_show_raster():
-    """
-    This test only verifies that code up to the point of plotting with
-    matplotlib works correctly.  Tests do not exercise matplotlib.
-    """
+
+def test_show_raster_band():
+    """Test plotting a single raster band."""
+    matplotlib = pytest.importorskip('matplotlib')
     with rasterio.open('tests/data/RGB.byte.tif') as src:
-        try:
-            show((src, 1))
-            fig = plt.gcf()
-            plt.close(fig)
-        except ImportError:
-            pass
+        show((src, 1))
+        fig = plt.gcf()
+        plt.close(fig)
 
-        with rasterio.open('tests/data/RGB.byte.tif') as src:
-            try:
-                show(src)
-                fig = plt.gcf()
-                plt.close(fig)
-            except ImportError:
-                pass
+def test_show_raster_mult_bands():
+    """Test multiple bands plotting."""
+    matplotlib = pytest.importorskip('matplotlib')
+    with rasterio.open('tests/data/RGB.byte.tif') as src:
+        show((src, (1, 2, 3)))
+        fig = plt.gcf()
+        plt.close(fig)
+
+def test_show_raster_object():
+    """Test plotting a raster object."""
+    matplotlib = pytest.importorskip('matplotlib')
+    with rasterio.open('tests/data/RGB.byte.tif') as src:
+        show(src)
+        fig = plt.gcf()
+        plt.close(fig)
+
+def test_show_raster_float():
+    """Test plotting a raster object with float data."""
+    matplotlib = pytest.importorskip('matplotlib')
+    with rasterio.open('tests/data/float.tif') as src:
+        show(src)
+        fig = plt.gcf()
+        plt.close(fig)
 
-        with rasterio.open('tests/data/float.tif') as src:
-            try:
-                show(src)
-                fig = plt.gcf()
-                plt.close(fig)
-            except ImportError:
-                pass
 
 def test_show_cmyk_interp(tmpdir):
     """A CMYK TIFF has cyan, magenta, yellow, black bands."""
+    matplotlib = pytest.importorskip('matplotlib')
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         meta = src.meta
-    meta['photometric'] = 'CMYK'
+    meta['photometric'] = 'cmyk'
     meta['count'] = 4
     tiffname = str(tmpdir.join('foo.tif'))
     with rasterio.open(tiffname, 'w', **meta) as dst:
-        assert dst.profile['photometric'] == 'cmyk'
-        assert dst.colorinterp(1) == ColorInterp.cyan
-        assert dst.colorinterp(2) == ColorInterp.magenta
-        assert dst.colorinterp(3) == ColorInterp.yellow
-        assert dst.colorinterp(4) == ColorInterp.black
+        assert dst.colorinterp == (
+            ColorInterp.cyan,
+            ColorInterp.magenta,
+            ColorInterp.yellow,
+            ColorInterp.black)
 
     with rasterio.open(tiffname) as src:
         try:
@@ -66,13 +74,13 @@ def test_show_cmyk_interp(tmpdir):
         except ImportError:
             pass
 
-@pytest.mark.skipif(plt is None,
-                    reason="requires matplotlib")
+
 def test_show_raster_no_bounds():
     """
     This test only verifies that code up to the point of plotting with
     matplotlib works correctly.  Tests do not exercise matplotlib.
     """
+    matplotlib = pytest.importorskip('matplotlib')
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         try:
             show((src, 1), with_bounds=False)
@@ -81,13 +89,13 @@ def test_show_raster_no_bounds():
         except ImportError:
             pass
 
-@pytest.mark.skipif(plt is None,
-                    reason="requires matplotlib")
+
 def test_show_raster_title():
     """
     This test only verifies that code up to the point of plotting with
     matplotlib works correctly.  Tests do not exercise matplotlib.
     """
+    matplotlib = pytest.importorskip('matplotlib')
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         try:
             show((src, 1), title="insert title here")
@@ -96,13 +104,12 @@ def test_show_raster_title():
         except ImportError:
             pass
 
-@pytest.mark.skipif(plt is None,
-                    reason="requires matplotlib")
 def test_show_hist_large():
     """
     This test only verifies that code up to the point of plotting with
     matplotlib works correctly.  Tests do not exercise matplotlib.
     """
+    matplotlib = pytest.importorskip('matplotlib')
     try:
         rand_arr = np.random.randn(10, 718, 791)
         show_hist(rand_arr)
@@ -111,13 +118,12 @@ def test_show_hist_large():
     except ImportError:
         pass
 
-@pytest.mark.skipif(plt is None,
-                    reason="requires matplotlib")
 def test_show_raster_cmap():
     """
     This test only verifies that code up to the point of plotting with
     matplotlib works correctly.  Tests do not exercise matplotlib.
     """
+    matplotlib = pytest.importorskip('matplotlib')
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         try:
             show((src, 1), cmap='jet')
@@ -126,13 +132,12 @@ def test_show_raster_cmap():
         except ImportError:
             pass
 
-@pytest.mark.skipif(plt is None,
-                    reason="requires matplotlib")
 def test_show_raster_ax():
     """
     This test only verifies that code up to the point of plotting with
     matplotlib works correctly.  Tests do not exercise matplotlib.
     """
+    matplotlib = pytest.importorskip('matplotlib')
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         try:
             fig, ax = plt.subplots(1)
@@ -142,13 +147,12 @@ def test_show_raster_ax():
         except ImportError:
             pass
 
-@pytest.mark.skipif(plt is None,
-                    reason="requires matplotlib")
 def test_show_array():
     """
     This test only verifies that code up to the point of plotting with
     matplotlib works correctly.  Tests do not exercise matplotlib.
     """
+    matplotlib = pytest.importorskip('matplotlib')
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         try:
             show(src.read(1))
@@ -157,13 +161,13 @@ def test_show_array():
         except ImportError:
             pass
 
-@pytest.mark.skipif(plt is None,
-                    reason="requires matplotlib")
+
 def test_show_array3D():
     """
     This test only verifies that code up to the point of plotting with
     matplotlib works correctly.  Tests do not exercise matplotlib.
     """
+    matplotlib = pytest.importorskip('matplotlib')
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         try:
             show(src.read((1, 2, 3)))
@@ -172,13 +176,12 @@ def test_show_array3D():
         except ImportError:
             pass
 
-@pytest.mark.skipif(plt is None,
-                    reason="requires matplotlib")
 def test_show_hist():
     """
     This test only verifies that code up to the point of plotting with
     matplotlib works correctly.  Tests do not exercise matplotlib.
     """
+    matplotlib = pytest.importorskip('matplotlib')
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         try:
             show_hist((src, 1), bins=256)
@@ -202,29 +205,27 @@ def test_show_hist():
         except ImportError:
             pass
 
-@pytest.mark.skipif(plt is None,
-                    reason="requires matplotlib")
 def test_show_hist_mplargs():
     """
     This test only verifies that code up to the point of plotting with
     matplotlib works correctly.  Tests do not exercise matplotlib.
     """
+    matplotlib = pytest.importorskip('matplotlib')
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         try:
-            show_hist(src, bins=50, lw=0.0, stacked=False, alpha=0.3, 
+            show_hist(src, bins=50, lw=0.0, stacked=False, alpha=0.3,
                histtype='stepfilled', title="World Histogram overlaid")
             fig = plt.gcf()
             plt.close(fig)
         except ImportError:
             pass
 
-@pytest.mark.skipif(plt is None,
-                    reason="requires matplotlib")
 def test_show_contour():
     """
     This test only verifies that code up to the point of plotting with
     matplotlib works correctly.  Tests do not exercise matplotlib.
     """
+    matplotlib = pytest.importorskip('matplotlib')
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         try:
             show((src, 1), contour=True)
@@ -233,16 +234,15 @@ def test_show_contour():
         except ImportError:
             pass
 
-@pytest.mark.skipif(plt is None,
-                    reason="requires matplotlib")
 def test_show_contour_mplargs():
     """
     This test only verifies that code up to the point of plotting with
     matplotlib works correctly.  Tests do not exercise matplotlib.
     """
+    matplotlib = pytest.importorskip('matplotlib')
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         try:
-            show((src, 1), contour=True, 
+            show((src, 1), contour=True,
                 levels=[25, 125], colors=['white', 'red'], linewidths=4,
                 contour_label_kws=dict(fontsize=18, fmt="%1.0f", inline_spacing=15, use_clabeltext=True))
             fig = plt.gcf()
@@ -250,15 +250,38 @@ def test_show_contour_mplargs():
         except ImportError:
             pass
 
-@pytest.mark.skipif(plt is None,
-                    reason="requires matplotlib")
 def test_get_plt():
     """
     This test only verifies that code up to the point of plotting with
     matplotlib works correctly.  Tests do not exercise matplotlib.
     """
-    with rasterio.open('tests/data/RGB.byte.tif') as src:
+    matplotlib = pytest.importorskip('matplotlib')
+    with rasterio.open('tests/data/RGB.byte.tif'):
         try:
             assert plt == get_plt()
         except ImportError:
-            pass
\ No newline at end of file
+            pass
+
+def test_plt_transform():
+    matplotlib = pytest.importorskip('matplotlib')
+    with rasterio.open('tests/data/RGB.byte.tif') as src:
+        show(src.read(), transform=src.transform)
+        show(src.read(1), transform=src.transform)
+
+def test_plotting_extent():
+    from rasterio.plot import reshape_as_image
+    expected = (101985.0, 339315.0, 2611485.0, 2826915.0)
+    with rasterio.open('tests/data/RGB.byte.tif') as src:
+        assert plotting_extent(src) == expected
+        assert plotting_extent(
+            reshape_as_image(src.read()), transform=src.transform) == expected
+        assert plotting_extent(
+            src.read(1), transform=src.transform) == expected
+        # array requires a transform
+        with pytest.raises(ValueError):
+            plotting_extent(src.read(1))
+
+def test_plot_normalize():
+    a = np.linspace(1, 6, 10)
+    b = adjust_band(a, 'linear')
+    np.testing.assert_array_almost_equal(np.linspace(0, 1, 10), b)
