@@ -1,6 +1,7 @@
 from click.testing import CliRunner
 
 import rasterio
+from rasterio.rio.main import main_group
 from rasterio.rio.stack import stack
 
 
@@ -8,9 +9,7 @@ def test_stack(tmpdir):
     outputname = str(tmpdir.join('stacked.tif'))
     runner = CliRunner()
     result = runner.invoke(
-        stack,
-        ['tests/data/RGB.byte.tif', outputname],
-        catch_exceptions=False)
+        main_group, ['stack', 'tests/data/RGB.byte.tif', outputname])
     assert result.exit_code == 0
     with rasterio.open(outputname) as out:
         assert out.count == 3
@@ -21,8 +20,8 @@ def test_stack_list(tmpdir):
     outputname = str(tmpdir.join('stacked.tif'))
     runner = CliRunner()
     result = runner.invoke(
-        stack,
-        ['tests/data/RGB.byte.tif', '--bidx', '1,2,3', outputname])
+        main_group, [
+            'stack', 'tests/data/RGB.byte.tif', '--bidx', '1,2,3', outputname])
     assert result.exit_code == 0
     with rasterio.open(outputname) as out:
         assert out.count == 3
@@ -32,8 +31,8 @@ def test_stack_slice(tmpdir):
     outputname = str(tmpdir.join('stacked.tif'))
     runner = CliRunner()
     result = runner.invoke(
-        stack,
-        [
+        main_group, [
+            'stack',
             'tests/data/RGB.byte.tif', '--bidx', '..2',
             'tests/data/RGB.byte.tif', '--bidx', '3..',
             outputname])
@@ -46,12 +45,11 @@ def test_stack_single_slice(tmpdir):
     outputname = str(tmpdir.join('stacked.tif'))
     runner = CliRunner()
     result = runner.invoke(
-        stack,
-        [
+        main_group, [
+            'stack',
             'tests/data/RGB.byte.tif', '--bidx', '1',
             'tests/data/RGB.byte.tif', '--bidx', '2..',
-            '--rgb',
-            outputname])
+            '--rgb', outputname])
     assert result.exit_code == 0
     with rasterio.open(outputname) as out:
         assert out.count == 3
@@ -61,8 +59,9 @@ def test_format_jpeg(tmpdir):
     outputname = str(tmpdir.join('stacked.jpg'))
     runner = CliRunner()
     result = runner.invoke(
-        stack,
-        ['tests/data/RGB.byte.tif', outputname, '--format', 'JPEG'])
+        main_group, [
+            'stack', 'tests/data/RGB.byte.tif', outputname,
+            '--format', 'JPEG'])
     assert result.exit_code == 0
 
 
@@ -70,6 +69,7 @@ def test_error(tmpdir):
     outputname = str(tmpdir.join('stacked.tif'))
     runner = CliRunner()
     result = runner.invoke(
-        stack,
-        ['tests/data/RGB.byte.tif', outputname, '--driver', 'BOGUS'])
+        main_group, [
+            'stack', 'tests/data/RGB.byte.tif', outputname,
+            '--driver', 'BOGUS'])
     assert result.exit_code == 1
